/*
 * This file is (c) Copyright Zarafa, The Netherlands, 2007
 *
 * Use of this file and the source contained within it is subject to the
 * license of the package it belongs to. See the LICENSE file in the
 * top-level directory of the package.
 *
 */

#ifndef INETMAPI_H
#define INETMAPI_H

/* WARNING */
/* mapidefs.h may not be included _before_ any vmime include! */

#include <ECLogger.h>
#include <mapix.h>
#include <mapidefs.h>
#include "options.h"

#ifdef _WIN32
# ifdef INETMAPI_EXPORTS
#  define INETMAPI_API __declspec(dllexport)
# else
#  define INETMAPI_API __declspec(dllimport)
# endif
#else
/* we do not need this on linux */
# define INETMAPI_API
#endif

// Sender Base class
// implementation of smtp sender in ECVMIMEUtils as ECVMIMESender
class ECSender {
protected:
	std::string smtphost;
	std::string error;
	int smtpresult;

	ECLogger *lpLogger;
	bool delete_logger;

public:
	ECSender(ECLogger *newlpLogger, std::string strSMTPHost);
	virtual	~ECSender();

	virtual int getSMTPResult();
	virtual const char* getErrorString();
	virtual void setError(std::string newError);
};

/* c wrapper to create object */
INETMAPI_API ECSender* CreateSender(ECLogger *lpLogger, std::string smtp);

// Read char Buffer and set properties on open lpMessage object
INETMAPI_API HRESULT IMToMAPI(IMAPISession *lpSession, IMessage *lpMessage, string input, delivery_options dopt, ECLogger *lpLogger = NULL);

// Read properties from lpMessage object and fill a buffer with internet rfc822 format message
// Use this one for retrieving messages not in outgoing que, they allready have PR_SENDER_EMAIL/NAME
// This can be used in making pop3 / imap server

// Read properties from lpMessage object and fill buffer with internet rfc822 format message
INETMAPI_API HRESULT IMToINet(IMAPISession *lpSession, IMessage *lpMessage, char** lppbuf, sending_options sopt, ECLogger *lpLogger = NULL);

// Read properties from lpMessage object and output to stream with internet rfc822 format message
INETMAPI_API HRESULT IMToINet(IMAPISession *lpSession, IMessage *lpMessage, std::ostream &os, sending_options sopt, ECLogger *lpLogger = NULL);

// Read properties from lpMessage object and send using  lpSMTPHost
INETMAPI_API HRESULT IMToINet(IMAPISession *lpSession, IMessage *lpMessage, ECSender *mailer, sending_options sopt, ECLogger *lpLogger);

#endif // INETMAPI_H
